
:mod:`emir.recipes` --- Reduction Recipes for EMIR
==================================================

.. module:: emir.recipes
   :synopsis:  Reduction Recipes for EMIR

Recipes for auxiliary modes
----------------------------

.. class:: BiasRecipe

   Bias Recipe

.. class:: DarkRecipe

   Dark Recipe

.. class:: IntensityFlatRecipe

   Intensity Flat Recipe

Recipes for image modes
-----------------------

.. class:: StareImageRecipe

   Stare Image Recipe

.. class:: StareImageRecipeInput

   Stare Image Recipe Input

.. class:: StareImageRecipeResult

   Stare Image Recipe Result


.. class:: DitheredImageRecipe

   Dithered Image Recipe

.. class:: NBImageRecipe

   Nodded/Beam-switched Image Recipe

.. class:: MicroDitheredImageRecipe

   Micro Dithered Image Recipe


Recipes for engineering
-----------------------

.. class:: CosmeticsRecipe

   .. versionadded:: 0.6.8

   Cosmetics Recipe
